imports property

List<String>? imports
final

Additional imports required by the generated code.

Note: Since generated code is in part files, these imports must be added to the parent file. This list serves as documentation for what imports are needed.

Implementation

final List<String>? imports;