refreshes property
List of types to emit refresh signals for on successful completion.
When the generated method completes successfully, it will call the configured refresh function for each type in this list.
Example:
@Generate(apiClient: ProfileApi, refreshes: [Profile, Dashboard])
Future<Either<Failure, UpdateResponse>> updateProfile(...);
Implementation
final List<Type> refreshes;